# 
# Copyright (c) 2015, 2020, Oracle and/or its affiliates. All rights reserved.
#
# This software is dual-licensed to you under the MIT License (MIT) and the Universal Permissive License (UPL).  See the LICENSE file in the root directory for license terms.  You may choose
# either license, or both.
#
ifneq ($(OPENSSL_URL), )
	OPENSSL_ARCH=$(notdir $(OPENSSL_URL) )
	OPENSSL_NAME=$(subst .tar.gz,,$(OPENSSL_ARCH))
else
	ifneq ($(OPENSSL_PATH), )
		OPENSSL_ARCH=$(notdir $(OPENSSL_PATH) )
		OPENSSL_NAME=$(subst .tar.gz,,$(OPENSSL_ARCH))
	else
		OPENSSL_ARCH=$(OPENSSL_NAME).tar.gz
		# Get just the numeric part of the version (minus the letter suffix).
		OPENSSL_VERSION_WITH_LETTER=$(subst openssl-,,${OPENSSL_NAME})
		OPENSSL_VERSION_MINUS_LETTER=$(shell echo ${OPENSSL_VERSION_WITH_LETTER} | sed -e s/[A-Za-z]//g)
		OPENSSL_URL="https://www.openssl.org/source/$(OPENSSL_ARCH)"
		# Older versions of Open SSL are moved here.
		OPENSSL_URL_ARCHIVE="https://www.openssl.org/source/old/$(OPENSSL_VERSION_MINUS_LETTER)/$(OPENSSL_ARCH)"
	endif
endif

ifneq ($(OPENSSL_PATH), )
    DOWNLOAD_COMMAND=cp -f "$(OPENSSL_PATH)" ./$(OPENSSL_ARCH) 2>&1
else
    ifneq ($(PROXY), )
        DOWNLOAD_COMMAND=export https_proxy="$(PROXY)"; wget $(OPENSSL_URL) 2>&1
        DOWNLOAD_COMMAND_ARCHIVE=export https_proxy="$(PROXY)"; wget $(OPENSSL_URL_ARCHIVE) 2>&1
    else
        DOWNLOAD_COMMAND=echo "WARNING: No HTTPS proxy is set for download. Usage: 'make -f Makefile.lib.mk PORT=windows download_dependencies [OPENSSL_PATH=<PATH TO OPENSSL.TAR.GZ> | PROXY=https://<YOUR PROXY URL>]'"; echo ""; wget $(OPENSSL_URL) 2>&1
        DOWNLOAD_COMMAND_ARCHIVE=echo "WARNING: No HTTPS proxy is set for download. Usage: 'make -f Makefile.lib.mk PORT=windows download_dependencies [OPENSSL_PATH=<PATH TO OPENSSL.TAR.GZ> | PROXY=https://<YOUR PROXY URL>]'"; echo ""; wget $(OPENSSL_URL_ARCHIVE) 2>&1
    endif
endif

$(OPENSSL)/$(OPENSSL_ARCH):
	mkdir -p $(dir $@)
	cd $(OPENSSL); $(DOWNLOAD_COMMAND)
	$(info $(RVAL))

		#ifneq ($(OPENSSL_VERSION_MINUS_LETTER), )
		# OPENSSL_URL is not overwridden on the command line (which means we used our default OPENSSL_URL) and it failed,
		# try to download from OPENSSL_URL_ARCHIVE as we don't know if the version the user specified is located in source
		# or source/old.
		#	RVAL := $(DOWNLOAD_COMMAND_ARCHIVE)
		#	$(info $(RVAL))
		#endif

$(OPENSSL)/$(OPENSSL_ARCH_FOLDER)/unpacked: $(OPENSSL)/$(OPENSSL_ARCH)
	$(A)tar -xvf $? -C "$(shell cd $(dir $(OPENSSL)/$(OPENSSL_ARCH)); pwd)"
	$(A)touch $(OPENSSL)/$(OPENSSL_ARCH_FOLDER)/unpacked

download_dependencies: $(OPENSSL)/$(OPENSSL_ARCH_FOLDER)/unpacked
	@printf 'openssl download finished!';

clean_dependencies:
	$(A)rm $(OPENSSL)/$(OPENSSL_ARCH)
	$(A)rm -rf $(OPENSSL)/$(OPENSSL_ARCH_FOLDER)

